@@ -5,6 +5,12 @@ use colored::Colorize;
 
 //<Specific part of CLI handling>
 //
+#[derive(Debug,PartialEq,Eq)]
+pub enum OutputOnly {
+    Filenames,
+    Folders,
+}
+//
 //Represents parsed CLI options
 #[derive(Debug,PartialEq,Eq)]
 pub struct Options {
@@ -12,10 +18,10 @@ pub struct Options {
     pub roots: Vec<String>,
     pub verbose_level: i32,
     pub use_relative_paths: bool,
-    pub output_filenames_only: bool,
+    pub output_only: std::option::Option<OutputOnly>,
     pub null_separated_output: bool,
     pub search_hidden_files: bool,
-    pub search_hidden_folders: bool,
+    pub search_ignored_files: bool,
     pub search_pattern_opt: std::option::Option<String>,
     pub replace_opt: std::option::Option<String>,
     pub simulate_replace: bool,
@@ -38,10 +44,10 @@ impl Default for Options {
             roots: vec![],
             verbose_level: 0,
             use_relative_paths: false,
-            output_filenames_only: false,
+            output_only: None,
             null_separated_output: false,
             search_hidden_files: false,
-            search_hidden_folders: false,
+            search_ignored_files: false,
             search_pattern_opt: None,
             replace_opt: None,
             simulate_replace: false,
@@ -81,7 +87,11 @@ fn generate_option_vec() -> Vec<Option> {
             Ok(())
         })),
         Option::new("-l", "--filenames-only", "Output only filenames [false]", Handler::Args0(|options|{
-            options.output_filenames_only = true;
+            options.output_only = Some(OutputOnly::Filenames);
+            Ok(())
+        })),
+        Option::new("-L", "--folders-only", "Output only folders [false]", Handler::Args0(|options|{
+            options.output_only = Some(OutputOnly::Folders);
             Ok(())
         })),
         Option::new("-0", "--null", "NULL-separated filename output [false]", Handler::Args0(|options|{
@@ -92,8 +102,8 @@ fn generate_option_vec() -> Vec<Option> {
             options.search_hidden_files = true;
             Ok(())
         })),
-        Option::new("-U", "--hidden-folders", "Search hidden folders as well [false]", Handler::Args0(|options|{
-            options.search_hidden_folders = true;
+        Option::new("-U", "--ignored-files", "Search ignored files as well [false]", Handler::Args0(|options|{
+            options.search_ignored_files = true;
             Ok(())
         })),
         Option::new("-p", "--pattern", "Use search regex PATTERN", Handler::Args1("PATTERN", |options, pattern|{
